dbtest

package
v0.0.0-...-8f1971e Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 19, 2026 License: Apache-2.0 Imports: 7 Imported by: 0

Documentation

Overview

Package dbtest provides test helpers for spinning up a Postgres container.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Start

func Start(ctx context.Context) (connStr string, cleanup func(), err error)

Start starts a pgvector Postgres container and returns the connection string and a cleanup function. Callers are responsible for calling cleanup when done.

func StartT

func StartT(ctx context.Context, t *testing.T) string

StartT starts a pgvector Postgres container and registers cleanup with t.Cleanup. Suitable for use in individual tests or test helpers that have a *testing.T.

Types

This section is empty.

Jump to